@@ -37,6 +37,9 @@ OBJECT_TYPE_TREE = "tree"
 OBJECT_TYPE_BLOB = "blob"
 OBJECT_TYPE_TAG = "tag"
 
+FLAG_CUSTOM_FORMAT = "--custom-format"
+FORMAT_PREFIX = "--pretty=format:"
+
 title_untracked = _('New files, uncommitted and not checked in to index')
 title_unstaged = _('Local uncommitted changes, not checked in to index')
 title_unstaged_and_untracked = formatter.format(_('{title_unstaged} and {title_untracked:l}'), title_unstaged=title_unstaged, title_untracked=title_untracked)
@@ -156,6 +159,22 @@ class Model(Runner):
 		return out
 
 
+	def replace_custom_format(self, cmd):
+		if not self.are_several_commands(cmd):
+			cmd = [cmd]
+
+		out = []
+		for subcmd in cmd:
+			if "-g" in subcmd or "--walk-reflogs" in subcmd:
+				subcmd = [FORMAT_PREFIX + self.fmt_reflog if w == FLAG_CUSTOM_FORMAT else w for w in subcmd]
+				if subcmd[-1][:1] == '-':
+					subcmd.append('HEAD@{0}')
+			else:
+				subcmd = [FORMAT_PREFIX + self.fmt_log if w == FLAG_CUSTOM_FORMAT else w for w in subcmd]
+			out.append(subcmd)
+		return out
+
+
 	@staticmethod
 	def are_several_commands(cmd):
 		return isinstance(cmd[0], list)
@@ -233,7 +252,10 @@ class Model(Runner):
 
 class LogModel(Model):
 
-	cmd_log = [["$status"], ["git", "log", "--color", "--graph", "--date=relative", "--pretty=format:%Cred%h%Creset -^%C(yellow)%d%Creset %s %Cgreen(%cd) %C(bold blue)<%an>%Creset", "--abbrev-commit"]]
+	fmt_log    = "%Cred%h%Creset -^%C(yellow)%d%Creset %s %Cgreen(%cd) %C(bold blue)<%an>%Creset"
+	fmt_reflog = "%Cred%h %Creset%C(yellow)%gD%Creset^%C(yellow)%d%Creset %gs %Cgreen(%cd) %C(bold blue)<%gn>%Creset"
+
+	cmd_log = [["$status"], ["git", "log", "--color", "--graph", "--date=relative", FLAG_CUSTOM_FORMAT, "--abbrev-commit"]]
 	cmd_stash_list = ["git", "stash", "list", "--color", "--pretty=format:%C(cyan)* %Cred%gd%Creset - ^%s %Cgreen(%cr)%Creset", "--abbrev-commit"]
 	cmd_unreachable = ["git", "fsck", "--unreachable"]
 
@@ -245,6 +267,8 @@ class LogModel(Model):
 
 		if "--no-walk" in options and "--graph" in cmd:
 			cmd.remove("--graph")
+		elif ("-g" in options or "--walk-reflogs" in options) and "--graph" in cmd:
+			cmd.remove("--graph")
 
 		while "--no-graph" in options:
 			# remove all occurences of --graph in cmd
@@ -277,6 +301,9 @@ class LogModel(Model):
 	def remove_align_character(self):
 		align_char = ALIGN_CHAR
 		cls = type(self)
+		self.fmt_log = cls.fmt_log.replace(align_char, "", 1)
+		self.fmt_reflog = cls.fmt_reflog.replace(align_char, "", 1)
+
 		self.cmd_log = self.replace_characters_in_cmd(cls.cmd_log, align_char, "", 1)
 		self.cmd_stash_list = self.replace_characters_in_cmd(cls.cmd_stash_list, align_char, "", 1)
 
@@ -285,6 +312,9 @@ class LogModel(Model):
 
 	def restore_align_character(self):
 		cls = type(self)
+		self.fmt_log = cls.fmt_log
+		self.fmt_reflog = cls.fmt_reflog
+
 		self.cmd_log = cls.cmd_log
 		self.cmd_stash_list = cls.cmd_stash_list
 
@@ -310,6 +340,7 @@ class LogModel(Model):
 		"""return a list of 3-tuples (line, id, type), each representing one line"""
 		# committed changes
 		self.cmd = self.cmd_log
+		self.cmd = self.replace_custom_format(self.cmd)
 		try:
 			lines = super().get_lines()
 		except CommandError as e:
@@ -390,7 +421,7 @@ class LogModel(Model):
 		return log
 
 	status.arguments = ''
-	status.description = _('show stashed, untracked, unstaged and staged changes if existing')
+	status.description = _('Show stashed, untracked, unstaged and staged changes if existing')
 	status.settings = [
 		'log-view.show-untracked',
 		'log-view.show-untracked-as-separate-group',
@@ -480,13 +511,15 @@ class UnreachableModel(LogModel):
 			ln = utils.colored_str_to_markup(ln, self.app.define_color)
 			return [(ln, None, TYPE_ERROR)]
 
-		if self.are_several_commands(LogModel.cmd_log):
-			self.cmd_log = self._copy_command(LogModel.cmd_log[-1])
+		original_cmd_log = self.cmd_log
+		if self.are_several_commands(self.cmd_log):
+			self.cmd_log = self._copy_command(self.cmd_log[-1])
 		else:
-			self.cmd_log = self._copy_command(LogModel.cmd_log)
+			self.cmd_log = self._copy_command(self.cmd_log)
 		self.append_cmd_log.__func__(self, ["--no-walk"])
 		self.cmd_log += lines
 		log = LogModel.get_lines(self)
+		self.cmd_log = original_cmd_log
 		return log
 
 
@@ -546,17 +579,19 @@ class DetailsModel(Model):
 		'--left-right',
 	)
 
-	_diff_commands = [cmd_pattern, cmd_unstaged, cmd_staged, cmd_pattern_stashed, cmd_start_header_data]
+	_diff_commands = ['cmd_pattern', 'cmd_unstaged', 'cmd_staged', 'cmd_pattern_stashed', 'cmd_start_header_data']
 
 
 	@classmethod
 	def append_cmd_diff(cls, options):
 		for cmd in cls._diff_commands:
+			cmd = getattr(cls, cmd)
 			cls._append_cmd(cmd, options)
 
 	@classmethod
 	def remove_cmd_diff(cls, options):
 		for cmd in cls._diff_commands:
+			cmd = getattr(cls, cmd)
 			cls._remove_cmd(cmd, options)
 
 	@classmethod
@@ -564,6 +599,7 @@ class DetailsModel(Model):
 		sum_added = 0
 		sum_removed = 0
 		for cmd in cls._diff_commands:
+			cmd = getattr(cls, cmd)
 			added, removed = cls._toggle_cmd(cmd, options)
 			sum_added += added
 			sum_removed += removed
@@ -590,9 +626,13 @@ class DetailsModel(Model):
 
 	def remove_align_character(self):
 		self.insert_align_character = False
+		self.fmt_log = LogModel.fmt_log.replace(ALIGN_CHAR, "", 1)
+		self.cmd_referencing_commits = self.replace_characters_in_cmd(type(self).cmd_referencing_commits, ALIGN_CHAR, "", 1)
 
 	def restore_align_character(self):
 		self.insert_align_character = True
+		self.fmt_log = LogModel.fmt_log
+		self.cmd_referencing_commits = type(self).cmd_referencing_commits
 
 
 	decoration_head_branch_sep = " -> "
@@ -936,6 +976,7 @@ class DetailsModel(Model):
 
 		bak = self.cmd
 		self.cmd = self.cmd_referencing_commits +  ["--grep", r"\<"+short_hash]
+		self.cmd = self.replace_custom_format(self.cmd)
 		try:
 			out = super().get_lines()
 		except CommandError as e:
@@ -951,7 +992,7 @@ class DetailsModel(Model):
 		return out
 
 	referencedby.arguments = 'CURRENT_COMMIT_HASH'
-	referencedby.description = _('show a list of commits referencing the current commit')
+	referencedby.description = _('Show a list of commits referencing the current commit')
 	referencedby.settings = ['details-view.cmd.commit.referenced-by', 'details-view.commit.line-pattern-referenced-by']
 
 	def untracked(self, args):
@@ -977,7 +1018,7 @@ class DetailsModel(Model):
 		return files
 
 	untracked.arguments = ''
-	untracked.description = _('return untracked files')
+	untracked.description = _('Return untracked files')
 	untracked.settings = ['details-view.show-untracked-relative-to']
 
 	indent_body = _("    ")
@@ -1102,7 +1143,7 @@ class DetailsModel(Model):
 		return decoration
 
 	commitheader.arguments = 'CURRENT_COMMIT_HASH'
-	commitheader.description = _('show the meta info of the current commit (hash, branch, tag, author, committer, date, message)')
+	commitheader.description = _('Show the meta info of the current commit (hash, branch, tag, author, committer, date, message)')
 	commitheader.settings = [
 		'details-view.cmd.commit.header-data',
 		'details-view.commit.user-pattern',
@@ -1127,6 +1168,8 @@ class DiffModel(DetailsModel):
 
 	cmd = ['git', 'diff', '--color']
 
+	_diff_commands = ['cmd']
+
 	def __init__(self, args):
 		self.hash_id = None
 		self.id_type = None
@@ -1141,7 +1184,6 @@ class DiffModel(DetailsModel):
 		self.setting_cmd = "details-view.cmd.diff"
 		self.cmd = type(self).cmd + self.args
 
-DetailsModel._diff_commands.append(DiffModel.cmd)
 
 
 # ---------- modifiers ----------
@@ -1171,12 +1213,21 @@ def append_cmd_unreachable(unreachable_args):
 
 def append_cmd_diff(diff_args):
 	DetailsModel.append_cmd_diff(diff_args)
+	DiffModel.append_cmd_diff(diff_args)
 
 def remove_cmd_diff(diff_args):
 	DetailsModel.remove_cmd_diff(diff_args)
+	DiffModel.remove_cmd_diff(diff_args)
 
 def toggle_cmd_diff(log_args):
-	return DetailsModel.toggle_cmd_diff(log_args)
+	sum_added = 0
+	sum_removed = 0
+	for cls in (DetailsModel, DiffModel):
+		added, removed = cls.toggle_cmd_diff(log_args)
+		sum_added += added
+		sum_removed += removed
+
+	return sum_added, sum_removed
 
 
 # ---------- getters ----------
